==> JDFLibJ-2.1.7.6-sources.jar: org/cip4/jdflib/auto/JDFAutochoice.java <==
/*
 * The CIP4 Software License, Version 1.0
 *
 *
 * Copyright (c) 2001-2020 The International Cooperation for the Integration of
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
  *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG
 * copyright (c) 1999-2001, Agfa-Gevaert N.V.
 *
 * For more information on The International Cooperation for the
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *
 *
 */

package org.cip4.jdflib.auto;

import java.util.Collection;

import org.apache.xerces.dom.CoreDocumentImpl;
import org.cip4.jdflib.core.ElemInfoTable;
import org.cip4.jdflib.core.ElementInfo;
import org.cip4.jdflib.core.ElementName;
import org.cip4.jdflib.core.JDFElement;
import org.cip4.jdflib.resource.devicecapability.JDFotherwise;
import org.cip4.jdflib.resource.devicecapability.JDFwhen;

/**
 *****************************************************************************
 * class JDFAutochoice : public JDFElement
 *****************************************************************************
 *
 */

public abstract class JDFAutochoice extends JDFElement
{

	private static final long serialVersionUID = 1L;

	private static ElemInfoTable[] elemInfoTable = new ElemInfoTable[2];
	static
	{
		elemInfoTable[0] = new ElemInfoTable(ElementName.WHEN, 0x22222211);
		elemInfoTable[1] = new ElemInfoTable(ElementName.OTHERWISE, 0x66666611);
	}

	@Override
	protected ElementInfo getTheElementInfo()
	{
		return super.getTheElementInfo().updateReplace(elemInfoTable);
	}

	/**
	 * Constructor for JDFAutochoice
	 *
	 * @param myOwnerDocument
	 * @param qualifiedName
	 */
	protected JDFAutochoice(CoreDocumentImpl myOwnerDocument, String qualifiedName)
	{
		super(myOwnerDocument, qualifiedName);
	}

	/**
	 * Constructor for JDFAutochoice
	 *
	 * @param myOwnerDocument
	 * @param myNamespaceURI
	 * @param qualifiedName
	 */
	protected JDFAutochoice(CoreDocumentImpl myOwnerDocument, String myNamespaceURI, String qualifiedName)
	{
		super(myOwnerDocument, myNamespaceURI, qualifiedName);
	}

	/**
	 * Constructor for JDFAutochoice
	 *
	 * @param myOwnerDocument
	 * @param myNamespaceURI
	 * @param qualifiedName
	 * @param myLocalName
	 */
	protected JDFAutochoice(CoreDocumentImpl myOwnerDocument, String myNamespaceURI, String qualifiedName, String myLocalName)
	{
		super(myOwnerDocument, myNamespaceURI, qualifiedName, myLocalName);
	}

	/* ***********************************************************************
	 * Element getter / setter
	 * ***********************************************************************
	 */

	/**
	 * (26) getCreatewhen
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFwhen the element
	 */
	public JDFwhen getCreatewhen(int iSkip)
	{
		return (JDFwhen) getCreateElement_JDFElement(ElementName.WHEN, null, iSkip);
	}

	/**
	 * (27) const get element when
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFwhen the element default is getwhen(0)
	 */
	public JDFwhen getwhen(int iSkip)
	{
		return (JDFwhen) getElement(ElementName.WHEN, null, iSkip);
	}

	/**
	 * Get all when from the current element
	 *
	 * @return Collection<JDFwhen>, null if none are available
	 */
	public Collection<JDFwhen> getAllwhen()
	{
		return getChildArrayByClass(JDFwhen.class, false, 0);
	}

	/**
	 * (30) append element when
	 *
	 * @return JDFwhen the element
	 */
	public JDFwhen appendwhen()
	{
		return (JDFwhen) appendElement(ElementName.WHEN, null);
	}

	/**
	 * (24) const get element otherwise
	 *
	 * @return JDFotherwise the element
	 */
	public JDFotherwise getotherwise()
	{
		return (JDFotherwise) getElement(ElementName.OTHERWISE, null, 0);
	}

	/**
	 * (25) getCreateotherwise
	 *
	 * @return JDFotherwise the element
	 */
	public JDFotherwise getCreateotherwise()
	{
		return (JDFotherwise) getCreateElement_JDFElement(ElementName.OTHERWISE, null, 0);
	}

	/**
	 * (29) append element otherwise
	 *
	 * @return JDFotherwise the element @ if the element already exists
	 */
	public JDFotherwise appendotherwise()
	{
		return (JDFotherwise) appendElementN(ElementName.OTHERWISE, 1, null);
	}

}

==> JDFLibJ-2.1.8.2-sources.jar: org/cip4/jdflib/auto/JDFAutochoice.java <==
/*
 * The CIP4 Software License, Version 1.0
 *
 *
 * Copyright (c) 2001-2024 The International Cooperation for the Integration of
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
  *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG
 * copyright (c) 1999-2001, Agfa-Gevaert N.V.
 *
 * For more information on The International Cooperation for the
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *
 *
 */

package org.cip4.jdflib.auto;

import java.util.Collection;

import org.apache.xerces.dom.CoreDocumentImpl;
import org.cip4.jdflib.core.ElemInfoTable;
import org.cip4.jdflib.core.ElementInfo;
import org.cip4.jdflib.core.ElementName;
import org.cip4.jdflib.core.JDFElement;
import org.cip4.jdflib.resource.devicecapability.JDFotherwise;
import org.cip4.jdflib.resource.devicecapability.JDFwhen;

/**
 *****************************************************************************
 * class JDFAutochoice : public JDFElement
 *****************************************************************************
 * 
 */

public abstract class JDFAutochoice extends JDFElement
{

	private static final long serialVersionUID = 1L;

	private static ElemInfoTable[] elemInfoTable = new ElemInfoTable[2];
	static
	{
		elemInfoTable[0] = new ElemInfoTable(ElementName.WHEN, 0x2222222211l);
		elemInfoTable[1] = new ElemInfoTable(ElementName.OTHERWISE, 0x6666666611l);
	}

	@Override
	protected ElementInfo getTheElementInfo()
	{
		return super.getTheElementInfo().updateReplace(elemInfoTable);
	}

	/**
	 * Constructor for JDFAutochoice
	 *
	 * @param myOwnerDocument
	 * @param qualifiedName
	 */
	protected JDFAutochoice(CoreDocumentImpl myOwnerDocument, String qualifiedName)
	{
		super(myOwnerDocument, qualifiedName);
	}

	/**
	 * Constructor for JDFAutochoice
	 *
	 * @param myOwnerDocument
	 * @param myNamespaceURI
	 * @param qualifiedName
	 */
	protected JDFAutochoice(CoreDocumentImpl myOwnerDocument, String myNamespaceURI, String qualifiedName)
	{
		super(myOwnerDocument, myNamespaceURI, qualifiedName);
	}

	/**
	 * Constructor for JDFAutochoice
	 *
	 * @param myOwnerDocument
	 * @param myNamespaceURI
	 * @param qualifiedName
	 * @param myLocalName
	 */
	protected JDFAutochoice(CoreDocumentImpl myOwnerDocument, String myNamespaceURI, String qualifiedName, String myLocalName)
	{
		super(myOwnerDocument, myNamespaceURI, qualifiedName, myLocalName);
	}

	/*
	 * *********************************************************************** Element getter / setter ***********************************************************************
	 */

	/**
	 * (26) getCreatewhen
	 * 
	 * @param iSkip number of elements to skip
	 * @return JDFwhen the element
	 */
	public JDFwhen getCreatewhen(int iSkip)
	{
		return (JDFwhen) getCreateElement_JDFElement(ElementName.WHEN, null, iSkip);
	}

	/**
	 * (27) const get element when
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFwhen the element default is getwhen(0)
	 */
	public JDFwhen getwhen(int iSkip)
	{
		return (JDFwhen) getElement(ElementName.WHEN, null, iSkip);
	}

	/**
	 * Get all when from the current element
	 * 
	 * @return Collection<JDFwhen>, null if none are available
	 */
	public Collection<JDFwhen> getAllwhen()
	{
		return getChildArrayByClass(JDFwhen.class, false, 0);
	}

	/**
	 * (30) append element when
	 *
	 * @return JDFwhen the element
	 */
	public JDFwhen appendwhen()
	{
		return (JDFwhen) appendElement(ElementName.WHEN, null);
	}

	/**
	 * (24) const get element otherwise
	 *
	 * @return JDFotherwise the element
	 */
	public JDFotherwise getotherwise()
	{
		return (JDFotherwise) getElement(ElementName.OTHERWISE, null, 0);
	}

	/**
	 * (25) getCreateotherwise
	 * 
	 * @return JDFotherwise the element
	 */
	public JDFotherwise getCreateotherwise()
	{
		return (JDFotherwise) getCreateElement_JDFElement(ElementName.OTHERWISE, null, 0);
	}

	/**
	 * (29) append element otherwise
	 *
	 * @return JDFotherwise the element @ if the element already exists
	 */
	public JDFotherwise appendotherwise()
	{
		return (JDFotherwise) appendElementN(ElementName.OTHERWISE, 1, null);
	}

}
